==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-nb-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nb\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Linje"

, "Caller Id"
: "Samtale ID"

, "Start"
: "Start"

, "Connected"
: "Tilkoblet"

, "Disconnected"
: "Frakoblet"

, "Duration"
: "Varighet"

, "Ringing"
: "Ringer"

, "Direction"
: "Retning"

, "Source"
: "Kilde"

, "Destination"
: "Destinasjon"

, "Phone"
: ""

, "Phones"
: "Telefoner"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Nummer"

, "Cancel"
: "Avbryt"

, "Dial"
: "Ring"

, "Error"
: ""

, "Not possible to dial."
: ""

, "Edit phone settings"
: "Rediger telefon instillinger"

, "Dial number"
: "Ring nummer"

, "Initiate a new outgoing call"
: "Initsier en ny utgående samtale"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: ""

, "Work"
: ""

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Incoming call"
: "Innkommende samtale"

, "Outgoing call"
: "Utgående samtale"

, "unknown number"
: "ukjent nummer"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-nb-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nLanguage: nb\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Innkommende samtale"

, "Outgoing call"
: "Utgående samtale"

, "unknown number"
: "ukjent nummer"

, "Phone"
: ""

, "Line"
: "Linje"

, "Number"
: "Nummer"

, "Cancel"
: "Avbryt"

, "Dial"
: "Ring"

, "Error"
: ""

, "Not possible to dial."
: ""

, "Call contact"
: ""

, "Work"
: ""

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Edit phone settings"
: "Rediger telefon instillinger"

, "Dial number"
: "Ring nummer"

, "Initiate a new outgoing call"
: "Initsier en ny utgående samtale"

, "Phones"
: "Telefoner"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "Samtale ID"

, "Start"
: "Start"

, "Connected"
: "Tilkoblet"

, "Disconnected"
: "Frakoblet"

, "Duration"
: "Varighet"

, "Ringing"
: "Ringer"

, "Direction"
: "Retning"

, "Source"
: "Kilde"

, "Destination"
: "Destinasjon"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
